==> dde-shell_2.0.1.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Стиль індикатора</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Модний режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Практичний режим</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Класичний режим</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Центрований режим</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Ліворуч</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Розташування</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Вгорі</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Праворуч</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Показувати постійно</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Приховувати</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Розумне приховування</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Параметри бічної панелі</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>Вимкнути нетипове налаштовування</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.2.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Стиль індикатора</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Модний режим</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Практичний режим</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Класичний режим</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Центрований режим</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Ліворуч</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Розташування</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Режим</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Вгорі</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Праворуч</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стан</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Показувати постійно</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Приховувати</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Розумне приховування</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Параметри бічної панелі</translation>
    </message>
    <message>
        <source>Lock the Dock</source>
        <translation>Заблокувати панель</translation>
    </message>
</context>
</TS>
